@@ -10,6 +10,8 @@
 
 from copy import deepcopy
 import re
+import torch
+import torch.nn as nn
 
 from torch.utils.data.dataloader import DataLoader
 
@@ -33,27 +35,24 @@ class SimulatedServer(BaseServer):
     def select(self, client_list: list):
         return self.selector.select(client_list)
 
-    def update(self, model):
-        result = self.aggregator.agg(
-            Serializer.serialize_model(self.model),
-            Serializer.serialize_model(model),
-            server_model_version=self.model.get_model_version(),
-            client_model_version=model.get_model_version())
+    def update(self, model: nn.Module, **kwargs):
+        result = self.aggregator.agg(Serializer.serialize_model(self.model),
+                                     Serializer.serialize_model(model), **kwargs)
 
+        if not result:
+            self.logger.info('It\'s not time to update.')
+            return
         # print(self.model.get_model_version(), model.get_model_version())
         Deserializer.deserialize_model(self.model, result['param'])
         self.model.set_model_version(result['model_version'])
         self.model.set_model_time(result['model_time'])
         # print(result['model_version'], result['model_time'])
         self.logger.info(
-            f'get model version {result["model_version"]} at time {result["model_time"]}'
-        )
-        return deepcopy(self.model)
+            f'get model version {result["model_version"]} at time {result["model_time"]}')
+        return
 
     def evaluate(self, dataset):
-        dataloader = DataLoader(dataset,
-                                batch_size=self.args.batch_size,
-                                shuffle=False)
+        dataloader = DataLoader(dataset, batch_size=self.args.batch_size, shuffle=False)
         return self.evaluator.evaluate(dataloader=dataloader,
                                        model=self.model,
                                        device=self.args.device)
